==> nmail-php-patch-2.5.2-to-2.6.1.tgz: nmail/sadmin.php <==
<?
require_once('include/global.php');
require_once('sadmin_conf.inc.php');


// set
	$CFG['TITLE'] = '<b>ϼ</b>';


// skin view
	nskinset('sadmin', 'sadmin.html');
	include($NSKIN['view_layout']);



// [2010-06-04] ̷ ܿ α׷ Ʈ ȳ
// *  : ȳ  ʿ   κ ϼŵ  ƹ  ϴ.
	flush();
	$nm_reg = nm_register_get();

	if ($nm_reg['s_virus_scan'])
	{
			$vs = get_virus_scan_version();
			$alert = '';

			if ($vs['date'] != '')
			{
				$vs['date2'] = substr($vs['date'], 0, 10);
				if ($vs['date2'] <= date('Y-m-d', time()-(86400*30)))		// Ʈ ¥ 30 ̻   .
				{
					$alert = ' <br><br><font color=red>
					<b>- ̷ Ʈ ȳ</b> ( ֱ Ʈ : '.$vs['date2'].' )<br>
					&nbsp &nbsp  <u>̷ܿ  α׷ Ʈ ̷ ʰ ֽϴ.</u><br>
					&nbsp &nbsp &nbsp &nbsp  ֽ ̷    ȲԴϴ.<br>
					&nbsp &nbsp &nbsp &nbsp Ʈ  1Ⱓ ǰ ֽϴ.<br>
					&nbsp &nbsp &nbsp &nbsp ڼ  [<a href="'.$nmpath.'/snmail.php"><b><u> ȳ</u></b></a>]  ֽø ˴ϴ.</font><br>';
				}	// if()
			} else
			{
					$alert = ' <br><br><font color=red>
					<b>- ̷ Ʈ ȳ</b><br>
					&nbsp &nbsp  <u> α׷  ʰų,</u><br>
					&nbsp &nbsp &nbsp &nbsp <u> ̻ Ʈ  ʴ ǰԴϴ.</u><br>
					&nbsp &nbsp &nbsp &nbsp  ֽ ̷    ȲԴϴ.<br>
					&nbsp &nbsp &nbsp &nbsp Ʈ  1Ⱓ ǰ ֽϴ.<br>
					&nbsp &nbsp &nbsp &nbsp ڼ  [<a href="'.$nmpath.'/snmail.php"><b><u> ȳ</u></b></a>]  ֽø ˴ϴ.</font><br>';
			}	// if()

			if ($alert != '')
			{
				?>
					<script language="JavaScript">
					<!--
						document.getElementById('nmail_virus_alert').innerHTML = '<?= str_replace(array("\r\n", "\n"), "", $alert) ?>';
					//-->
					</script>
				<?				
			}	// if()
		?><?
	}	// if()


// [2013-07-15] ֽ  Ȯ
	$url = 'http://www.passkorea.net/nmailphp/version_check.txt';
	$pu = parse_url($url);
	if ($pu['port'] == '')
		$pu['port'] = 80;

	$result = array();
	$result['code'] = 0;
	$result['msg'] = '';
	$fp = @fsockopen($pu['host'], $pu['port'], $errno, $errstr, 10);
	if (!$fp) {
		$result['msg'] = "HTTP connect fail. ".$errstr." (".$errno.")";
	} else {
	   fputs($fp, "GET ".$pu['path']."?".$pu['query']." HTTP/1.0\r\nHost: ".$pu['host']."\r\n\r\n");

	   while (!feof($fp)) {
		   $result['msg'] .= fgets ($fp,128);
	   }
	   fclose ($fp);

	   if (trim($result['msg']) != '')
	   {
		   $result['code'] = 1;
		   $ex = explode("\r\n\r\n", $result['msg']);
		   $result['msg'] = trim($ex[1]);
	   }	// if()
	}

	if (preg_match('/[0-9]+\.[0-9]+\.[0-9]+/', $result['msg']) && version_compare($result['msg'], NM_VER, '>'))		// 2.6.1.beta3 / 2.5.3.beta26.pl1 / 2.5.3.pl1 ϶ 2.6.1 Ʈ Ȯε. 2.6.1.pl1   Ȯε.
	{
		?>
			<script language="JavaScript">
			<!--
				document.getElementById('nmail_version_check').innerHTML = '<br><br><a href="http://www.passkorea.net/" target="_blank"><span style="color: red; font-size: 11pt; text-decoration: underline; font-weight: bold;">ֽ ( <?= $result['msg'] ?> ) ׷̵ Ȯϱ!!!</span></a>';
			//-->
			</script>
		<?				
	}	// if()

require_once('include/global_end.php');
?>

==> nmail-php-patch-2.6.1-to-2.6.12.tgz: nmail/sadmin.php <==
<?
require_once('include/global.php');
require_once('sadmin_conf.inc.php');


// set
	$CFG['TITLE'] = '<b>ϼ</b>';


// skin view
	nskinset('sadmin', 'sadmin.html');
	include($NSKIN['view_layout']);



// [2010-06-04] ̷ ܿ α׷ Ʈ ȳ
// *  : ȳ  ʿ   κ ϼŵ  ƹ  ϴ.
	flush();
	$nm_reg = nm_register_get();

	if ($nm_reg['s_virus_scan'])
	{
			$vs = get_virus_scan_version();
			$alert = '';

			if ($vs['date'] != '')
			{
				$vs['date2'] = substr($vs['date'], 0, 10);
				if ($vs['date2'] <= date('Y-m-d', time()-(86400*30)))		// Ʈ ¥ 30 ̻   .
				{
					$alert = ' <br><br><font color=red>
					<b>- ̷ Ʈ ȳ</b> ( ֱ Ʈ : '.$vs['date2'].' )<br>
					&nbsp &nbsp  <u>̷ܿ  α׷ Ʈ ̷ ʰ ֽϴ.</u><br>
					&nbsp &nbsp &nbsp &nbsp  ֽ ̷    ȲԴϴ.<br>
					&nbsp &nbsp &nbsp &nbsp Ʈ  1Ⱓ ǰ ֽϴ.<br>
					&nbsp &nbsp &nbsp &nbsp ڼ  [<a href="'.$nmpath.'/snmail.php"><b><u> ȳ</u></b></a>]  ֽø ˴ϴ.</font><br>';
				}	// if()
			} else
			{
					$alert = ' <br><br><font color=red>
					<b>- ̷ Ʈ ȳ</b><br>
					&nbsp &nbsp  <u> α׷  ʰų,</u><br>
					&nbsp &nbsp &nbsp &nbsp <u> ̻ Ʈ  ʴ ǰԴϴ.</u><br>
					&nbsp &nbsp &nbsp &nbsp  ֽ ̷    ȲԴϴ.<br>
					&nbsp &nbsp &nbsp &nbsp Ʈ  1Ⱓ ǰ ֽϴ.<br>
					&nbsp &nbsp &nbsp &nbsp ڼ  [<a href="'.$nmpath.'/snmail.php"><b><u> ȳ</u></b></a>]  ֽø ˴ϴ.</font><br>';
			}	// if()

			if ($alert != '')
			{
				?>
					<script language="JavaScript">
					<!--
						document.getElementById('nmail_virus_alert').innerHTML = '<?= str_replace(array("\r\n", "\n"), "", $alert) ?>';
					//-->
					</script>
				<?				
			}	// if()
		?><?
	}	// if()


// [2013-07-15] ֽ  Ȯ
	flush();
	$url = 'http://www.passkorea.net/nmailphp/version_check.txt';
	$pu = parse_url($url);
	if ($pu['port'] == '')
		$pu['port'] = 80;

	$result = array();
	$result['code'] = 0;
	$result['msg'] = '';
	$fp = @fsockopen($pu['host'], $pu['port'], $errno, $errstr, 10);
	if (!$fp) {
		$result['msg'] = "HTTP connect fail. ".$errstr." (".$errno.")";
	} else {
	   fputs($fp, "GET ".$pu['path']."?".$pu['query']." HTTP/1.0\r\nHost: ".$pu['host']."\r\n\r\n");

	   while (!feof($fp)) {
		   $result['msg'] .= fgets ($fp,128);
	   }
	   fclose ($fp);

	   if (trim($result['msg']) != '')
	   {
		   $result['code'] = 1;
		   $ex = explode("\r\n\r\n", $result['msg']);
		   $result['msg'] = trim($ex[1]);
	   }	// if()
	}

	if (preg_match('/[0-9]+\.[0-9]+\.[0-9]+/', $result['msg']) && version_compare($result['msg'], NM_VER, '>'))		// 2.6.1.beta3 / 2.5.3.beta26.pl1 / 2.5.3.pl1 ϶ 2.6.1 Ʈ Ȯε. 2.6.1.pl1   Ȯε.
	{
		?>
			<script language="JavaScript">
			<!--
				document.getElementById('nmail_version_check').innerHTML = '<br><br><a href="http://www.passkorea.net/" target="_blank"><span style="color: red; font-size: 11pt; text-decoration: underline; font-weight: bold;">ֽ ( <?= str_replace("'", "", $result['msg']) ?> ) ׷̵ Ȯϱ!!!</span></a>';
			//-->
			</script>
		<?				
	}	// if()


// [2013-08-29] SMTP   Ȯϱ
	flush();
	$fp = @fsockopen($G_SYS[SMTP_ADDR], $G_SYS[SMTP_PORT], $errno, $errstr, 10);
	if (!$fp) {
		$nmail_smtp_check = "  - ".$errstr." (".$errno.")";
	} else {
		$nmail_smtp_check = trim(fgets($fp,1024));
		fputs($fp, "QUIT\r\n");
		fclose($fp);
	}

	preg_match('/XMail [0-9\.]+ [a-z]+([0-9]+)/i', $nmail_smtp_check, $mc);
	if (is_numeric($mc[1]) && $mc[1] >= '120228')
	{
		$nmail_smtp_check = "ֽ  Ȯε˴ϴ.";
	} else {
		$nmail_smtp_check = '<span style="color: red; font-size: 11pt;">Ͽ ֽ  ƴմϴ.  ׷̵ ޴󿡼 [<b>Ͽ Ʈ</b>]׸ ȮϽʽÿ.</span><br> &nbsp; &nbsp;  &nbsp; &nbsp; SMTP  : '.$nmail_smtp_check;
		?>
			<script language="JavaScript">
			<!--
				document.getElementById('nmail_smtp_check').innerHTML = '<?= str_replace("'", "", $nmail_smtp_check) ?>';
			//-->
			</script>
		<?				
	}	// if()


require_once('include/global_end.php');
?>
